<?php
$resultsFile = __DIR__ . '/results.json';
$results = [];
$categories = [];
$products = [];

if (file_exists($resultsFile)) {
    $json = file_get_contents($resultsFile);
    $results = json_decode($json, true);
    foreach ($results as $row) {
        if (!empty($row['category']) && !in_array($row['category'], $categories)) {
            $categories[] = $row['category'];
        }
        if (!empty($row['product']) && !in_array($row['product'], $products)) {
            $products[] = $row['product'];
        }
    }
}

$selectedCategory = $_GET['category'] ?? '';
$selectedProduct = $_GET['product'] ?? '';
$keyword = $_GET['keyword'] ?? '';
?>

<!DOCTYPE html>
<html lang="ko">
<head>
  <meta charset="UTF-8">
  <title>OTTIE 문서 검색</title>
  <style>
    table { border-collapse: collapse; width: 100%; }
    th, td { padding: 8px 12px; border: 1px solid #ccc; }
    th { background-color: #f0f0f0; }
    input, select { padding: 6px; }
  </style>
</head>
<body>
  <h2>📄 OTTIE 문서 검색 및 분류 결과</h2>

  <form method="get" style="margin-bottom: 20px;">
    <label>📌 제품명:
      <select name="product">
        <option value="">-- 전체 --</option>
        <?php foreach ($products as $prod): ?>
          <option value="<?= htmlspecialchars($prod) ?>" <?= $prod === $selectedProduct ? 'selected' : '' ?>>
            <?= htmlspecialchars($prod) ?>
          </option>
        <?php endforeach; ?>
      </select>
    </label>

    <label>📂 분류:
      <select name="category">
        <option value="">-- 전체 --</option>
        <?php foreach ($categories as $cat): ?>
          <option value="<?= htmlspecialchars($cat) ?>" <?= $cat === $selectedCategory ? 'selected' : '' ?>>
            <?= htmlspecialchars($cat) ?>
          </option>
        <?php endforeach; ?>
      </select>
    </label>

    <label>🔍 키워드:
      <input type="text" name="keyword" value="<?= htmlspecialchars($keyword) ?>" placeholder="파일명 검색">
    </label>

    <button type="submit">검색</button>
  </form>

  <?php
  $filtered = array_filter($results, function ($r) use ($selectedCategory, $selectedProduct, $keyword) {
      return (!$selectedCategory || $r['category'] === $selectedCategory)
          && (!$selectedProduct || $r['product'] === $selectedProduct)
          && (!$keyword || stripos($r['filename'], $keyword) !== false);
  });
  ?>

  <?php if (empty($filtered)): ?>
    <p>⚠ 검색 조건에 맞는 문서가 없습니다.</p>
  <?php else: ?>
    <table>
      <tr>
        <th>파일명</th>
        <th>유형</th>
        <th>제품명</th>
        <th>카테고리</th>
        <th>열기</th>
      </tr>
      <?php foreach ($filtered as $row): ?>
        <tr>
          <td><?= htmlspecialchars($row['filename']) ?></td>
          <td><?= strtoupper($row['type']) ?></td>
          <td><?= htmlspecialchars($row['product'] ?? '-') ?></td>
          <td><?= htmlspecialchars($row['category'] ?? '-') ?></td>
          <td><a href="<?= htmlspecialchars($row['path']) ?>" target="_blank">열기</a></td>
        </tr>
      <?php endforeach; ?>
    </table>
  <?php endif; ?>
</body>
</html>
